# התחל!

ברוכים הבאים ל-Rapunzel, סביבת פיתוח מודרנית עבור Python ו-R. הנה כמה קיצורי דרך מועילים.


## עבודה עם תיקיות פרויקט וקבצים

- [`Ctrl+Shift+O`: פתיחת תיקיית פרויקט](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: פתיחת קובץ מתיקיות הפרויקט](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: יצירת מסמך ריק](opensesame://event.ide_new_file)


## לבצע דברים במהירות

- [`Ctrl+Shift+P`: הפעלת לוח הפקודות](opensesame://event.command_palette_activate)
- `Ctrl+R`: קפיצה אל פונקציה או מחלקה


## הרצת קוד

- `F5`: הרצת הפרויקט או הקובץ
- `F9`: הרצת בחירה, תא או השורה הנוכחית